pub struct PKPaymentAuthorizationViewController { /* private fields */ }objc2-app-kit and crate feature PKPaymentAuthorizationViewController only.Expand description
Implementations
Sourceimpl PKPaymentAuthorizationViewController
impl PKPaymentAuthorizationViewController
pub unsafe fn canMakePayments(mtm: MainThreadMarker) -> bool
pub unsafe fn canMakePaymentsUsingNetworks( supported_networks: &NSArray<PKPaymentNetwork>, mtm: MainThreadMarker, ) -> bool
PKConstants only.pub unsafe fn canMakePaymentsUsingNetworks_capabilities( supported_networks: &NSArray<PKPaymentNetwork>, capabilties: PKMerchantCapability, mtm: MainThreadMarker, ) -> bool
PKConstants and PKPaymentRequest only.pub unsafe fn delegate( &self, ) -> Option<Retained<ProtocolObject<dyn PKPaymentAuthorizationViewControllerDelegate>>>
PKPaymentAuthorizationViewControllerDelegate only.Sourcepub unsafe fn setDelegate(
&self,
delegate: Option<&ProtocolObject<dyn PKPaymentAuthorizationViewControllerDelegate>>,
)
Available on crate feature PKPaymentAuthorizationViewControllerDelegate only.
pub unsafe fn setDelegate( &self, delegate: Option<&ProtocolObject<dyn PKPaymentAuthorizationViewControllerDelegate>>, )
PKPaymentAuthorizationViewControllerDelegate only.Setter for delegate.
This is a weak property.
pub unsafe fn initWithPaymentRequest( this: Allocated<Self>, request: &PKPaymentRequest, ) -> Option<Retained<Self>>
PKPaymentRequest only.pub unsafe fn supportsDisbursements(mtm: MainThreadMarker) -> bool
pub unsafe fn supportsDisbursementsUsingNetworks( supported_networks: &NSArray<PKPaymentNetwork>, mtm: MainThreadMarker, ) -> bool
PKConstants only.pub unsafe fn supportsDisbursementsUsingNetworks_capabilities( supported_networks: &NSArray<PKPaymentNetwork>, capabilities: PKMerchantCapability, mtm: MainThreadMarker, ) -> bool
PKConstants and PKPaymentRequest only.pub unsafe fn initWithDisbursementRequest( this: Allocated<Self>, request: &PKDisbursementRequest, ) -> Retained<Self>
PKDisbursementRequest only.Sourceimpl PKPaymentAuthorizationViewController
Methods declared on superclass NSViewController.
impl PKPaymentAuthorizationViewController
Methods declared on superclass NSViewController.
Sourceimpl PKPaymentAuthorizationViewController
Methods declared on superclass NSResponder.
impl PKPaymentAuthorizationViewController
Methods declared on superclass NSResponder.
Sourceimpl PKPaymentAuthorizationViewController
Methods declared on superclass NSObject.
impl PKPaymentAuthorizationViewController
Methods declared on superclass NSObject.
pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>
Methods from Deref<Target = NSViewController>
pub fn nibName(&self) -> Option<Retained<NSString>>
NSNib and NSResponder only.pub fn nibBundle(&self) -> Option<Retained<NSBundle>>
NSResponder only.pub fn representedObject(&self) -> Option<Retained<AnyObject>>
NSResponder only.Sourcepub unsafe fn setRepresentedObject(
&self,
represented_object: Option<&AnyObject>,
)
Available on crate feature NSResponder only.
pub unsafe fn setRepresentedObject( &self, represented_object: Option<&AnyObject>, )
NSResponder only.pub fn title(&self) -> Option<Retained<NSString>>
NSResponder only.pub fn view(&self) -> Retained<NSView>
NSResponder and NSView only.Sourcepub fn setView(&self, view: &NSView)
Available on crate features NSResponder and NSView only.
pub fn setView(&self, view: &NSView)
NSResponder and NSView only.Setter for view.
pub fn viewIfLoaded(&self) -> Option<Retained<NSView>>
NSResponder and NSView only.pub fn loadView(&self)
NSResponder only.pub fn loadViewIfNeeded(&self)
NSResponder only.Sourcepub unsafe fn commitEditingWithDelegate_didCommitSelector_contextInfo(
&self,
delegate: Option<&AnyObject>,
did_commit_selector: Option<Sel>,
context_info: *mut c_void,
)
Available on crate feature NSResponder only.
pub unsafe fn commitEditingWithDelegate_didCommitSelector_contextInfo( &self, delegate: Option<&AnyObject>, did_commit_selector: Option<Sel>, context_info: *mut c_void, )
NSResponder only.Safety
delegateshould be of the correct type.did_commit_selectormust be a valid selector.context_infomust be a valid pointer or null.
pub fn commitEditing(&self) -> bool
NSResponder only.pub fn discardEditing(&self)
NSResponder only.pub fn viewDidLoad(&self)
NSResponder only.pub fn isViewLoaded(&self) -> bool
NSResponder only.pub fn viewWillAppear(&self)
NSResponder only.pub fn viewDidAppear(&self)
NSResponder only.pub fn viewWillDisappear(&self)
NSResponder only.pub fn viewDidDisappear(&self)
NSResponder only.pub fn preferredContentSize(&self) -> CGSize
NSResponder only.Sourcepub fn setPreferredContentSize(&self, preferred_content_size: CGSize)
Available on crate feature NSResponder only.
pub fn setPreferredContentSize(&self, preferred_content_size: CGSize)
NSResponder only.Setter for preferredContentSize.
pub fn updateViewConstraints(&self)
NSResponder only.pub fn viewWillLayout(&self)
NSResponder only.pub fn viewDidLayout(&self)
NSResponder only.pub fn presentViewController_animator( &self, view_controller: &NSViewController, animator: &ProtocolObject<dyn NSViewControllerPresentationAnimator>, )
NSResponder only.pub fn dismissViewController(&self, view_controller: &NSViewController)
NSResponder only.Sourcepub unsafe fn dismissController(&self, sender: Option<&AnyObject>)
Available on crate feature NSResponder only.
pub unsafe fn dismissController(&self, sender: Option<&AnyObject>)
NSResponder only.Safety
sender should be of the correct type.
pub fn presentedViewControllers( &self, ) -> Option<Retained<NSArray<NSViewController>>>
NSResponder only.Sourcepub unsafe fn presentingViewController(
&self,
) -> Option<Retained<NSViewController>>
Available on crate feature NSResponder only.
pub unsafe fn presentingViewController( &self, ) -> Option<Retained<NSViewController>>
NSResponder only.Safety
This is not retained internally, you must ensure the object is still alive.
pub fn presentViewControllerAsSheet(&self, view_controller: &NSViewController)
NSResponder only.pub fn presentViewControllerAsModalWindow( &self, view_controller: &NSViewController, )
NSResponder only.pub fn parentViewController(&self) -> Option<Retained<NSViewController>>
NSResponder only.pub fn childViewControllers(&self) -> Retained<NSArray<NSViewController>>
NSResponder only.Sourcepub fn setChildViewControllers(
&self,
child_view_controllers: &NSArray<NSViewController>,
)
Available on crate feature NSResponder only.
pub fn setChildViewControllers( &self, child_view_controllers: &NSArray<NSViewController>, )
NSResponder only.Setter for childViewControllers.
This is copied when set.
pub fn addChildViewController(&self, child_view_controller: &NSViewController)
NSResponder only.pub fn removeFromParentViewController(&self)
NSResponder only.pub fn insertChildViewController_atIndex( &self, child_view_controller: &NSViewController, index: isize, )
NSResponder only.pub fn removeChildViewControllerAtIndex(&self, index: isize)
NSResponder only.pub fn preferredContentSizeDidChangeForViewController( &self, view_controller: &NSViewController, )
NSResponder only.pub fn viewWillTransitionToSize(&self, new_size: CGSize)
NSResponder only.pub fn extensionContext(&self) -> Option<Retained<NSExtensionContext>>
NSResponder only.pub fn sourceItemView(&self) -> Option<Retained<NSView>>
NSResponder and NSView only.Sourcepub fn setSourceItemView(&self, source_item_view: Option<&NSView>)
Available on crate features NSResponder and NSView only.
pub fn setSourceItemView(&self, source_item_view: Option<&NSView>)
NSResponder and NSView only.Setter for sourceItemView.
pub fn preferredScreenOrigin(&self) -> CGPoint
NSResponder only.Sourcepub fn setPreferredScreenOrigin(&self, preferred_screen_origin: CGPoint)
Available on crate feature NSResponder only.
pub fn setPreferredScreenOrigin(&self, preferred_screen_origin: CGPoint)
NSResponder only.Setter for preferredScreenOrigin.
pub fn preferredMinimumSize(&self) -> CGSize
NSResponder only.pub fn preferredMaximumSize(&self) -> CGSize
NSResponder only.Methods from Deref<Target = NSResponder>
Sourcepub unsafe fn nextResponder(&self) -> Option<Retained<NSResponder>>
pub unsafe fn nextResponder(&self) -> Option<Retained<NSResponder>>
Safety
This is not retained internally, you must ensure the object is still alive.
Sourcepub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)
pub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)
Setter for nextResponder.
Safety
This is unretained, you must ensure the object is kept alive while in use.
Sourcepub unsafe fn tryToPerform_with(
&self,
action: Sel,
object: Option<&AnyObject>,
) -> bool
pub unsafe fn tryToPerform_with( &self, action: Sel, object: Option<&AnyObject>, ) -> bool
Safety
actionmust be a valid selector.objectshould be of the correct type.
Sourcepub unsafe fn noResponderFor(&self, event_selector: Sel)
pub unsafe fn noResponderFor(&self, event_selector: Sel)
Safety
event_selector must be a valid selector.
pub fn acceptsFirstResponder(&self) -> bool
pub fn becomeFirstResponder(&self) -> bool
pub fn resignFirstResponder(&self) -> bool
pub fn flushBufferedKeyEvents(&self)
Sourcepub unsafe fn showContextHelp(&self, sender: Option<&AnyObject>)
pub unsafe fn showContextHelp(&self, sender: Option<&AnyObject>)
Safety
sender should be of the correct type.
Sourcepub unsafe fn supplementalTargetForAction_sender(
&self,
action: Sel,
sender: Option<&AnyObject>,
) -> Option<Retained<AnyObject>>
pub unsafe fn supplementalTargetForAction_sender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>
Safety
actionmust be a valid selector.sendershould be of the correct type.
pub fn undoManager(&self) -> Option<Retained<NSUndoManager>>
Sourcepub unsafe fn presentError_modalForWindow_delegate_didPresentSelector_contextInfo(
&self,
error: &NSError,
window: &NSWindow,
delegate: Option<&AnyObject>,
did_present_selector: Option<Sel>,
context_info: *mut c_void,
)
Available on crate feature NSWindow only.
pub unsafe fn presentError_modalForWindow_delegate_didPresentSelector_contextInfo( &self, error: &NSError, window: &NSWindow, delegate: Option<&AnyObject>, did_present_selector: Option<Sel>, context_info: *mut c_void, )
NSWindow only.Safety
delegateshould be of the correct type.did_present_selectormust be a valid selector.context_infomust be a valid pointer or null.
pub fn presentError(&self, error: &NSError) -> bool
pub fn willPresentError(&self, error: &NSError) -> Retained<NSError>
Sourcepub unsafe fn performTextFinderAction(&self, sender: Option<&AnyObject>)
pub unsafe fn performTextFinderAction(&self, sender: Option<&AnyObject>)
Safety
sender should be of the correct type.
Sourcepub unsafe fn newWindowForTab(&self, sender: Option<&AnyObject>)
pub unsafe fn newWindowForTab(&self, sender: Option<&AnyObject>)
Safety
sender should be of the correct type.
Sourcepub unsafe fn showWritingTools(&self, sender: Option<&AnyObject>)
pub unsafe fn showWritingTools(&self, sender: Option<&AnyObject>)
Safety
sender should be of the correct type.
pub fn performMnemonic(&self, string: &NSString) -> bool
This has always returned NO and had no effect on macOS
Methods from Deref<Target = NSObject>
Sourcepub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !
Handle messages the object doesn’t recognize.
See Apple’s documentation for details.
Methods from Deref<Target = AnyObject>
Sourcepub fn class(&self) -> &'static AnyClass
pub fn class(&self) -> &'static AnyClass
Dynamically find the class of this object.
Panics
May panic if the object is invalid (which may be the case for objects
returned from unavailable init/new methods).
Example
Check that an instance of NSObject has the precise class NSObject.
use objc2::ClassType;
use objc2::runtime::NSObject;
let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());Sourcepub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
👎Deprecated: this is difficult to use correctly, use Ivar::load instead.
pub unsafe fn get_ivar<T>(&self, name: &str) -> &Twhere
T: Encode,
this is difficult to use correctly, use Ivar::load instead.
Use Ivar::load instead.
Safety
The object must have an instance variable with the given name, and it
must be of type T.
See Ivar::load_ptr for details surrounding this.
Sourcepub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
pub fn downcast_ref<T>(&self) -> Option<&T>where
T: DowncastTarget,
Attempt to downcast the object to a class of type T.
This is the reference-variant. Use Retained::downcast if you want
to convert a retained object to another type.
Mutable classes
Some classes have immutable and mutable variants, such as NSString
and NSMutableString.
When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.
So using this method to convert a NSString to a NSMutableString,
while not unsound, is generally frowned upon unless you created the
string yourself, or the API explicitly documents the string to be
mutable.
See Apple’s documentation on mutability and on
isKindOfClass: for more details.
Generic classes
Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.
You can, however, safely downcast to generic collections where all the
type-parameters are AnyObject.
Panics
This works internally by calling isKindOfClass:. That means that the
object must have the instance method of that name, and an exception
will be thrown (if CoreFoundation is linked) or the process will abort
if that is not the case. In the vast majority of cases, you don’t need
to worry about this, since both root objects NSObject and
NSProxy implement this method.
Examples
Cast an NSString back and forth from NSObject.
use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};
let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();Try (and fail) to cast an NSObject to an NSString.
use objc2_foundation::{NSObject, NSString};
let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());Try to cast to an array of strings.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.
Downcast when processing each element instead.
use objc2_foundation::{NSArray, NSObject, NSString};
let arr = NSArray::from_retained_slice(&[NSObject::new()]);
for elem in arr {
if let Some(data) = elem.downcast_ref::<NSString>() {
// handle `data`
}
}Trait Implementations
Sourceimpl AsRef<NSResponder> for PKPaymentAuthorizationViewController
impl AsRef<NSResponder> for PKPaymentAuthorizationViewController
Sourcefn as_ref(&self) -> &NSResponder
fn as_ref(&self) -> &NSResponder
Sourceimpl AsRef<NSViewController> for PKPaymentAuthorizationViewController
impl AsRef<NSViewController> for PKPaymentAuthorizationViewController
Sourcefn as_ref(&self) -> &NSViewController
fn as_ref(&self) -> &NSViewController
Sourceimpl Borrow<NSResponder> for PKPaymentAuthorizationViewController
impl Borrow<NSResponder> for PKPaymentAuthorizationViewController
Sourcefn borrow(&self) -> &NSResponder
fn borrow(&self) -> &NSResponder
Sourceimpl Borrow<NSViewController> for PKPaymentAuthorizationViewController
impl Borrow<NSViewController> for PKPaymentAuthorizationViewController
Sourcefn borrow(&self) -> &NSViewController
fn borrow(&self) -> &NSViewController
Sourceimpl ClassType for PKPaymentAuthorizationViewController
impl ClassType for PKPaymentAuthorizationViewController
Sourceconst NAME: &'static str = "PKPaymentAuthorizationViewController"
const NAME: &'static str = "PKPaymentAuthorizationViewController"
Sourcetype Super = NSViewController
type Super = NSViewController
Sourcetype ThreadKind = <<PKPaymentAuthorizationViewController as ClassType>::Super as ClassType>::ThreadKind
type ThreadKind = <<PKPaymentAuthorizationViewController as ClassType>::Super as ClassType>::ThreadKind
Sourceimpl NSCoding for PKPaymentAuthorizationViewController
impl NSCoding for PKPaymentAuthorizationViewController
Sourceunsafe fn encodeWithCoder(&self, coder: &NSCoder)
unsafe fn encodeWithCoder(&self, coder: &NSCoder)
NSCoder only.Sourceimpl NSEditor for PKPaymentAuthorizationViewController
impl NSEditor for PKPaymentAuthorizationViewController
fn discardEditing(&self)
fn commitEditing(&self) -> bool
Sourceunsafe fn commitEditingWithDelegate_didCommitSelector_contextInfo(
&self,
delegate: Option<&AnyObject>,
did_commit_selector: Option<Sel>,
context_info: *mut c_void,
)
unsafe fn commitEditingWithDelegate_didCommitSelector_contextInfo( &self, delegate: Option<&AnyObject>, did_commit_selector: Option<Sel>, context_info: *mut c_void, )
fn commitEditingAndReturnError(&self) -> Result<(), Retained<NSError>>
Sourceimpl NSObjectProtocol for PKPaymentAuthorizationViewController
impl NSObjectProtocol for PKPaymentAuthorizationViewController
Sourcefn isEqual(&self, other: Option<&AnyObject>) -> bool
fn isEqual(&self, other: Option<&AnyObject>) -> bool
Sourcefn hash(&self) -> usize
fn hash(&self) -> usize
Sourcefn isKindOfClass(&self, cls: &AnyClass) -> bool
fn isKindOfClass(&self, cls: &AnyClass) -> bool
Sourcefn is_kind_of<T>(&self) -> bool
fn is_kind_of<T>(&self) -> bool
use isKindOfClass directly, or cast your objects with AnyObject::downcast_ref
Sourcefn isMemberOfClass(&self, cls: &AnyClass) -> bool
fn isMemberOfClass(&self, cls: &AnyClass) -> bool
Sourcefn respondsToSelector(&self, aSelector: Sel) -> bool
fn respondsToSelector(&self, aSelector: Sel) -> bool
Sourcefn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
fn conformsToProtocol(&self, aProtocol: &AnyProtocol) -> bool
Sourcefn debugDescription(&self) -> Retained<NSObject>
fn debugDescription(&self) -> Retained<NSObject>
Sourceimpl NSSeguePerforming for PKPaymentAuthorizationViewController
impl NSSeguePerforming for PKPaymentAuthorizationViewController
Sourceunsafe fn prepareForSegue_sender(
&self,
segue: &NSStoryboardSegue,
sender: Option<&AnyObject>,
)
unsafe fn prepareForSegue_sender( &self, segue: &NSStoryboardSegue, sender: Option<&AnyObject>, )
Sourceimpl RefEncode for PKPaymentAuthorizationViewController
impl RefEncode for PKPaymentAuthorizationViewController
Sourceconst ENCODING_REF: Encoding = <NSViewController as ::objc2::RefEncode>::ENCODING_REF
const ENCODING_REF: Encoding = <NSViewController as ::objc2::RefEncode>::ENCODING_REF
impl DowncastTarget for PKPaymentAuthorizationViewController
impl Eq for PKPaymentAuthorizationViewController