PKPaymentButton

Struct PKPaymentButton 

pub struct PKPaymentButton { /* private fields */ }
Available on macOS and crate feature objc2-app-kit and crate feature PKPaymentButton only.
Implementations

Source

impl PKPaymentButton

pub unsafe fn buttonWithType_style( button_type: PKPaymentButtonType, button_style: PKPaymentButtonStyle, mtm: MainThreadMarker, ) -> Retained<Self>

Available on crate feature PKConstants only.
pub unsafe fn initWithPaymentButtonType_paymentButtonStyle( this: Allocated<Self>, type: PKPaymentButtonType, style: PKPaymentButtonStyle, ) -> Retained<Self>

Available on crate feature PKConstants only.
pub unsafe fn buttonWithType_style_disableCardArt( button_type: PKPaymentButtonType, button_style: PKPaymentButtonStyle, disable_card_art: bool, mtm: MainThreadMarker, ) -> Retained<Self>

Available on crate feature PKConstants only.
pub unsafe fn initWithPaymentButtonType_paymentButtonStyle_disableCardArt( this: Allocated<Self>, type: PKPaymentButtonType, style: PKPaymentButtonStyle, disable_card_art: bool, ) -> Retained<Self>

Available on crate feature PKConstants only.
pub unsafe fn cornerRadius(&self) -> CGFloat

Available on crate feature objc2-core-foundation only.
pub unsafe fn setCornerRadius(&self, corner_radius: CGFloat)

Available on crate feature objc2-core-foundation only.

Setter for cornerRadius.

Source

impl PKPaymentButton

Methods declared on superclass NSButton.

pub unsafe fn buttonWithTitle_image_target_action( title: &NSString, image: &NSImage, target: Option<&AnyObject>, action: Option<Sel>, mtm: MainThreadMarker, ) -> Retained<Self>

Creates a standard push button with a title and image.

Parameter title: The localized title string that is displayed on the button.

Parameter image: The image that is displayed alongside the title. In left-to-right localizations, the image is displayed to the left of the title. In right-to-left localizations, it is displayed to the right.

Parameter target: The target object that receives action messages from the control.

Parameter action: The action message sent by the control.

Returns: An initialized button object.

Safety
  • target should be of the correct type.
  • action must be a valid selector.
pub unsafe fn buttonWithTitle_target_action( title: &NSString, target: Option<&AnyObject>, action: Option<Sel>, mtm: MainThreadMarker, ) -> Retained<Self>

Creates a standard push button with the provided title.

Parameter title: The localized title string that is displayed on the button.

Parameter target: The target object that receives action messages from the control.

Parameter action: The action message sent by the control.

Returns: An initialized button object.

Safety
  • target should be of the correct type.
  • action must be a valid selector.
pub unsafe fn buttonWithImage_target_action( image: &NSImage, target: Option<&AnyObject>, action: Option<Sel>, mtm: MainThreadMarker, ) -> Retained<Self>

Creates a standard push button with the provided image. Set the image’s accessibilityDescription property to ensure accessibility for this control.

Parameter image: The image to display in the body of the button.

Parameter target: The target object that receives action messages from the control.

Parameter action: The action message sent by the control.

Returns: An initialized button object.

Safety
  • target should be of the correct type.
  • action must be a valid selector.
pub unsafe fn checkboxWithTitle_target_action( title: &NSString, target: Option<&AnyObject>, action: Option<Sel>, mtm: MainThreadMarker, ) -> Retained<Self>

Creates a standard checkbox with the provided title.

Parameter title: The localized title string that is displayed alongside the checkbox.

Parameter target: The target object that receives action messages from the control.

Parameter action: The action message sent by the control.

Returns: An initialized button object.

Safety
  • target should be of the correct type.
  • action must be a valid selector.
pub unsafe fn radioButtonWithTitle_target_action( title: &NSString, target: Option<&AnyObject>, action: Option<Sel>, mtm: MainThreadMarker, ) -> Retained<Self>

Creates a standard radio button with the provided title.

Parameter title: The localized title string that is displayed alongside the radio button.

Parameter target: The target object that receives action messages from the control.

Parameter action: The action message sent by the control.

Returns: An initialized button object.

Safety
  • target should be of the correct type.
  • action must be a valid selector.
Source

impl PKPaymentButton

Methods declared on superclass NSControl.

pub unsafe fn initWithFrame( this: Allocated<Self>, frame_rect: NSRect, ) -> Retained<Self>

pub unsafe fn initWithCoder( this: Allocated<Self>, coder: &NSCoder, ) -> Option<Retained<Self>>

Safety

coder possibly has further requirements.

Source

impl PKPaymentButton

Methods declared on superclass NSResponder.

pub unsafe fn init(this: Allocated<Self>) -> Retained<Self>

Source

impl PKPaymentButton

Methods declared on superclass NSObject.

pub unsafe fn new(mtm: MainThreadMarker) -> Retained<Self>

Methods from Deref<Target = NSButton>

pub fn title(&self) -> Retained<NSString>

Available on crate features NSControl and NSResponder and NSView only.

The title displayed on the button when it’s in an off state, or an empty string if the button does not display a title. By default, a button’s title is “Button”.

pub fn setTitle(&self, title: &NSString)

Available on crate features NSControl and NSResponder and NSView only.

Setter for title.

This is copied when set.

pub fn attributedTitle(&self) -> Retained<NSAttributedString>

Available on crate features NSControl and NSResponder and NSView only.

The button’s title, expressed as an attributed string.

pub fn setAttributedTitle(&self, attributed_title: &NSAttributedString)

Available on crate features NSControl and NSResponder and NSView only.

Setter for attributedTitle.

This is copied when set.

pub fn alternateTitle(&self) -> Retained<NSString>

Available on crate features NSControl and NSResponder and NSView only.

The title that the button displays when the button is in an on state, or an empty string if there is no such title. Note that some button types do not display an alternate title.

pub fn setAlternateTitle(&self, alternate_title: &NSString)

Available on crate features NSControl and NSResponder and NSView only.

Setter for alternateTitle.

This is copied when set.

pub fn attributedAlternateTitle(&self) -> Retained<NSAttributedString>

Available on crate features NSControl and NSResponder and NSView only.

The alternate title, expressed as an attributed string.

pub fn setAttributedAlternateTitle( &self, attributed_alternate_title: &NSAttributedString, )

Available on crate features NSControl and NSResponder and NSView only.

Setter for attributedAlternateTitle.

This is copied when set.

pub fn hasDestructiveAction(&self) -> bool

Available on crate features NSControl and NSResponder and NSView only.

Indicates whether the button’s action has a destructive effect on user data. AppKit may guard a destructive-actioned button against accidental presses, and may give the button a special appearance in certain contexts to caution against unintentional use. Defaults to NO.

pub fn setHasDestructiveAction(&self, has_destructive_action: bool)

Available on crate features NSControl and NSResponder and NSView only.
pub fn isSpringLoaded(&self) -> bool

Available on crate features NSControl and NSResponder and NSView only.

Sends action on deep-press or extended hover while dragging. Defaults to NO.

pub fn setSpringLoaded(&self, spring_loaded: bool)

Available on crate features NSControl and NSResponder and NSView only.

Setter for isSpringLoaded.

pub fn maxAcceleratorLevel(&self) -> isize

Available on crate features NSControl and NSResponder and NSView only.

Configures the maximum allowed level for an NSMultiLevelAcceleratorButton, allowed values range from [1,5]. Defaults to 2.

pub fn setMaxAcceleratorLevel(&self, max_accelerator_level: isize)

Available on crate features NSControl and NSResponder and NSView only.

Setter for maxAcceleratorLevel.

pub fn setPeriodicDelay_interval(&self, delay: f32, interval: f32)

Available on crate features NSControl and NSResponder and NSView only.

Sets the initial delay and repeat interval, in seconds, for repeated action messages sent when continuous is YES.

pub unsafe fn getPeriodicDelay_interval( &self, delay: NonNull<f32>, interval: NonNull<f32>, )

Available on crate features NSControl and NSResponder and NSView only.

Gets the initial delay and repeat interval, in seconds, for repeated action messages sent when continuous is YES. Both parameters to this method must not be NULL.

Safety
  • delay must be a valid pointer.
  • interval must be a valid pointer.
pub fn isBordered(&self) -> bool

Available on crate features NSControl and NSResponder and NSView only.

A Boolean value that determines whether the button draws a border.

pub fn setBordered(&self, bordered: bool)

Available on crate features NSControl and NSResponder and NSView only.

Setter for isBordered.

pub fn isTransparent(&self) -> bool

Available on crate features NSControl and NSResponder and NSView only.

A Boolean value that indicates whether the button is transparent. A transparent button never draws itself, but it receives mouse events, sends its action, and tracks the mouse properly.

pub fn setTransparent(&self, transparent: bool)

Available on crate features NSControl and NSResponder and NSView only.

Setter for isTransparent.

pub fn showsBorderOnlyWhileMouseInside(&self) -> bool

Available on crate features NSControl and NSResponder and NSView only.
pub fn setShowsBorderOnlyWhileMouseInside( &self, shows_border_only_while_mouse_inside: bool, )

Available on crate features NSControl and NSResponder and NSView only.
pub fn image(&self) -> Option<Retained<NSImage>>

Available on crate features NSControl and NSImage and NSResponder and NSView only.

The image that appears on the button when it’s in an off state, or nil if there is no such image.

pub fn setImage(&self, image: Option<&NSImage>)

Available on crate features NSControl and NSImage and NSResponder and NSView only.

Setter for image.

pub fn alternateImage(&self) -> Option<Retained<NSImage>>

Available on crate features NSControl and NSImage and NSResponder and NSView only.

An alternate image that appears on the button when the button is in an on state, or nil if there is no such image. Note that some button types do not display an alternate image.

pub fn setAlternateImage(&self, alternate_image: Option<&NSImage>)

Available on crate features NSControl and NSImage and NSResponder and NSView only.

Setter for alternateImage.

pub fn imageHugsTitle(&self) -> bool

Available on crate features NSControl and NSResponder and NSView only.

A Boolean value that determines how the button’s image and title are positioned together within the button bezel. If false, the image is positioned according to the imagePosition property at the edge of the button bezel, and the title is positioned within the remaining space. If true, the button’s image is positioned directly adjacent to the title based on the imagePosition property, and the image and title are positioned within the button bezel as a single unit.

pub fn setImageHugsTitle(&self, image_hugs_title: bool)

Available on crate features NSControl and NSResponder and NSView only.

Setter for imageHugsTitle.

pub fn symbolConfiguration( &self, ) -> Option<Retained<NSImageSymbolConfiguration>>

Available on crate features NSControl and NSImage and NSResponder and NSView only.

Specifies a combination of point size, weight, and scale to use when sizing and displaying symbol images. If a symbol configuration isn’t provided, the symbol is matched to the button’s font property. The default value is nil.

pub fn setSymbolConfiguration( &self, symbol_configuration: Option<&NSImageSymbolConfiguration>, )

Available on crate features NSControl and NSImage and NSResponder and NSView only.

Setter for symbolConfiguration.

This is copied when set.

pub fn allowsMixedState(&self) -> bool

Available on crate features NSControl and NSResponder and NSView only.

A Boolean value that indicates whether the button allows a mixed state. If NO, the button has two states (on and off), and if YES, the button has three states (on, off, and mixed). The mixed state is commonly used with checkboxes and radio buttons to indicate a value which is partially on.

pub fn setAllowsMixedState(&self, allows_mixed_state: bool)

Available on crate features NSControl and NSResponder and NSView only.

Setter for allowsMixedState.

pub fn setNextState(&self)

Available on crate features NSControl and NSResponder and NSView only.

Sets the button to its next eligible state. If the button allows mixed state, this cycles through the states in the order: on, off, mixed, on, etc. If the button does not allow mixed state, it toggles between off and on.

pub fn highlight(&self, flag: bool)

Available on crate features NSControl and NSResponder and NSView only.

Highlights, or un-highlights, the button. Highlighting makes the button appear “pressed”, which may include showing an illuminated bezel, or showing the alternate image or title, depending on the type of button.

pub fn keyEquivalent(&self) -> Retained<NSString>

Available on crate features NSControl and NSResponder and NSView only.

This property contains the button’s key equivalent, or the empty string if no equivalent has been defined. Buttons don’t have a default key equivalent. Setting the key equivalent to the Return character causes it to act as the default button for its window.

pub fn setKeyEquivalent(&self, key_equivalent: &NSString)

Available on crate features NSControl and NSResponder and NSView only.

Setter for keyEquivalent.

This is copied when set.

pub fn compressWithPrioritizedCompressionOptions( &self, prioritized_options: &NSArray<NSUserInterfaceCompressionOptions>, )

Available on crate features NSControl and NSResponder and NSUserInterfaceCompression and NSView only.
pub fn minimumSizeWithPrioritizedCompressionOptions( &self, prioritized_options: &NSArray<NSUserInterfaceCompressionOptions>, ) -> CGSize

Available on crate features NSControl and NSResponder and NSUserInterfaceCompression and NSView only.
pub fn activeCompressionOptions( &self, ) -> Retained<NSUserInterfaceCompressionOptions>

Available on crate features NSControl and NSResponder and NSUserInterfaceCompression and NSView only.
pub fn borderShape(&self) -> NSControlBorderShape

Available on crate features NSControl and NSResponder and NSView only.
pub fn setBorderShape(&self, border_shape: NSControlBorderShape)

Available on crate features NSControl and NSResponder and NSView only.

Setter for borderShape.

pub unsafe fn setTitleWithMnemonic( &self, string_with_ampersand: Option<&NSString>, )

👎Deprecated:

Mnemonics are not used on macOS. Set the title property directly instead.

Available on crate features NSControl and NSResponder and NSView only.
Safety

string_with_ampersand might not allow None.

Methods from Deref<Target = NSControl>

pub fn target(&self) -> Option<Retained<AnyObject>>

Available on crate features NSResponder and NSView only.
pub unsafe fn setTarget(&self, target: Option<&AnyObject>)

Available on crate features NSResponder and NSView only.

Setter for target.

This is a weak property.

Safety

target should be of the correct type.

pub fn action(&self) -> Option<Sel>

Available on crate features NSResponder and NSView only.
pub unsafe fn setAction(&self, action: Option<Sel>)

Available on crate features NSResponder and NSView only.

Setter for action.

Safety

action must be a valid selector.

pub fn tag(&self) -> isize

Available on crate features NSResponder and NSView only.
pub fn setTag(&self, tag: isize)

Available on crate features NSResponder and NSView only.

Setter for tag.

pub fn ignoresMultiClick(&self) -> bool

Available on crate features NSResponder and NSView only.
pub fn setIgnoresMultiClick(&self, ignores_multi_click: bool)

Available on crate features NSResponder and NSView only.

Setter for ignoresMultiClick.

pub fn isContinuous(&self) -> bool

Available on crate features NSResponder and NSView only.
pub fn setContinuous(&self, continuous: bool)

Available on crate features NSResponder and NSView only.

Setter for isContinuous.

pub fn isEnabled(&self) -> bool

Available on crate features NSResponder and NSView only.
pub fn setEnabled(&self, enabled: bool)

Available on crate features NSResponder and NSView only.

Setter for isEnabled.

pub fn refusesFirstResponder(&self) -> bool

Available on crate features NSResponder and NSView only.
pub fn setRefusesFirstResponder(&self, refuses_first_responder: bool)

Available on crate features NSResponder and NSView only.
pub fn isHighlighted(&self) -> bool

Available on crate features NSResponder and NSView only.
pub fn setHighlighted(&self, highlighted: bool)

Available on crate features NSResponder and NSView only.

Setter for isHighlighted.

pub fn formatter(&self) -> Option<Retained<NSFormatter>>

Available on crate features NSResponder and NSView only.
pub fn setFormatter(&self, formatter: Option<&NSFormatter>)

Available on crate features NSResponder and NSView only.

Setter for formatter.

pub fn objectValue(&self) -> Option<Retained<AnyObject>>

Available on crate features NSResponder and NSView only.
pub unsafe fn setObjectValue(&self, object_value: Option<&AnyObject>)

Available on crate features NSResponder and NSView only.

Setter for objectValue.

This is copied when set.

Safety

object_value should be of the correct type.

pub fn stringValue(&self) -> Retained<NSString>

Available on crate features NSResponder and NSView only.
pub fn setStringValue(&self, string_value: &NSString)

Available on crate features NSResponder and NSView only.

Setter for stringValue.

This is copied when set.

pub fn attributedStringValue(&self) -> Retained<NSAttributedString>

Available on crate features NSResponder and NSView only.
pub fn setAttributedStringValue( &self, attributed_string_value: &NSAttributedString, )

Available on crate features NSResponder and NSView only.

Setter for attributedStringValue.

This is copied when set.

pub fn intValue(&self) -> i32

Available on crate features NSResponder and NSView only.
pub fn setIntValue(&self, int_value: i32)

Available on crate features NSResponder and NSView only.

Setter for intValue.

pub fn integerValue(&self) -> isize

Available on crate features NSResponder and NSView only.
pub fn setIntegerValue(&self, integer_value: isize)

Available on crate features NSResponder and NSView only.

Setter for integerValue.

pub fn floatValue(&self) -> f32

Available on crate features NSResponder and NSView only.
pub fn setFloatValue(&self, float_value: f32)

Available on crate features NSResponder and NSView only.

Setter for floatValue.

pub fn doubleValue(&self) -> f64

Available on crate features NSResponder and NSView only.
pub fn setDoubleValue(&self, double_value: f64)

Available on crate features NSResponder and NSView only.

Setter for doubleValue.

pub fn sizeThatFits(&self, size: CGSize) -> CGSize

Available on crate features NSResponder and NSView only.
pub fn sizeToFit(&self)

Available on crate features NSResponder and NSView only.
pub unsafe fn sendAction_to( &self, action: Option<Sel>, target: Option<&AnyObject>, ) -> bool

Available on crate features NSResponder and NSView only.
Safety
  • action must be a valid selector.
  • target should be of the correct type.
pub unsafe fn takeIntValueFrom(&self, sender: Option<&AnyObject>)

Available on crate features NSResponder and NSView only.
Safety

sender should be of the correct type.

pub unsafe fn takeFloatValueFrom(&self, sender: Option<&AnyObject>)

Available on crate features NSResponder and NSView only.
Safety

sender should be of the correct type.

pub unsafe fn takeDoubleValueFrom(&self, sender: Option<&AnyObject>)

Available on crate features NSResponder and NSView only.
Safety

sender should be of the correct type.

pub unsafe fn takeStringValueFrom(&self, sender: Option<&AnyObject>)

Available on crate features NSResponder and NSView only.
Safety

sender should be of the correct type.

pub unsafe fn takeObjectValueFrom(&self, sender: Option<&AnyObject>)

Available on crate features NSResponder and NSView only.
Safety

sender should be of the correct type.

pub unsafe fn takeIntegerValueFrom(&self, sender: Option<&AnyObject>)

Available on crate features NSResponder and NSView only.
Safety

sender should be of the correct type.

pub unsafe fn performClick(&self, sender: Option<&AnyObject>)

Available on crate features NSResponder and NSView only.
Safety

sender should be of the correct type.

pub fn usesSingleLineMode(&self) -> bool

Available on crate features NSResponder and NSView only.
pub fn setUsesSingleLineMode(&self, uses_single_line_mode: bool)

Available on crate features NSResponder and NSView only.

Setter for usesSingleLineMode.

pub fn allowsExpansionToolTips(&self) -> bool

Available on crate features NSResponder and NSView only.
pub fn setAllowsExpansionToolTips(&self, allows_expansion_tool_tips: bool)

Available on crate features NSResponder and NSView only.
pub fn expansionFrameWithFrame(&self, content_frame: CGRect) -> CGRect

Available on crate features NSResponder and NSView only.
pub fn drawWithExpansionFrame_inView( &self, content_frame: CGRect, view: &NSView, )

Available on crate features NSResponder and NSView only.
pub fn abortEditing(&self) -> bool

Available on crate features NSResponder and NSView only.
pub fn validateEditing(&self)

Available on crate features NSResponder and NSView only.
pub fn setFloatingPointFormat_left_right( &self, auto_range: bool, left_digits: usize, right_digits: usize, )

👎Deprecated
Available on crate features NSResponder and NSView only.
pub fn selectedTag(&self) -> isize

Available on crate features NSResponder and NSView only.
pub fn setNeedsDisplay(&self)

👎Deprecated:

Set the needsDisplay property to YES instead

Available on crate features NSResponder and NSView only.
pub fn calcSize(&self)

👎Deprecated:

Override -layout instead. This method should never be called

Available on crate features NSResponder and NSView only.

Methods from Deref<Target = NSView>

pub fn window(&self) -> Option<Retained<NSWindow>>

Available on crate features NSResponder and NSWindow only.
pub unsafe fn superview(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub fn subviews(&self) -> Retained<NSArray<NSView>>

Available on crate feature NSResponder only.
pub fn setSubviews(&self, subviews: &NSArray<NSView>)

Available on crate feature NSResponder only.

Setter for subviews.

This is copied when set.

pub fn isDescendantOf(&self, view: &NSView) -> bool

Available on crate feature NSResponder only.
pub fn ancestorSharedWithView(&self, view: &NSView) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub unsafe fn opaqueAncestor(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub fn isHidden(&self) -> bool

Available on crate feature NSResponder only.
pub fn setHidden(&self, hidden: bool)

Available on crate feature NSResponder only.

Setter for isHidden.

pub fn isHiddenOrHasHiddenAncestor(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn getRectsBeingDrawn_count( &self, rects: *mut *const CGRect, count: *mut isize, )

Available on crate feature NSResponder only.
Safety
  • rects must be a valid pointer or null.
  • count must be a valid pointer or null.
pub fn needsToDrawRect(&self, rect: CGRect) -> bool

Available on crate feature NSResponder only.
pub fn wantsDefaultClipping(&self) -> bool

Available on crate feature NSResponder only.
pub fn viewDidHide(&self)

Available on crate feature NSResponder only.
pub fn viewDidUnhide(&self)

Available on crate feature NSResponder only.
pub fn addSubview(&self, view: &NSView)

Available on crate feature NSResponder only.
pub unsafe fn sortSubviewsUsingFunction_context( &self, compare: unsafe extern "C-unwind" fn(NonNull<NSView>, NonNull<NSView>, *mut c_void) -> NSComparisonResult, context: *mut c_void, )

Available on crate feature NSResponder only.
Safety
  • compare must be implemented correctly.
  • context must be a valid pointer or null.
pub fn viewWillMoveToWindow(&self, new_window: Option<&NSWindow>)

Available on crate features NSResponder and NSWindow only.
pub fn viewDidMoveToWindow(&self)

Available on crate feature NSResponder only.
pub fn viewWillMoveToSuperview(&self, new_superview: Option<&NSView>)

Available on crate feature NSResponder only.
pub fn viewDidMoveToSuperview(&self)

Available on crate feature NSResponder only.
pub fn didAddSubview(&self, subview: &NSView)

Available on crate feature NSResponder only.
pub fn willRemoveSubview(&self, subview: &NSView)

Available on crate feature NSResponder only.
pub fn removeFromSuperview(&self)

Available on crate feature NSResponder only.
pub fn replaceSubview_with(&self, old_view: &NSView, new_view: &NSView)

Available on crate feature NSResponder only.
pub fn removeFromSuperviewWithoutNeedingDisplay(&self)

Available on crate feature NSResponder only.
pub fn viewDidChangeBackingProperties(&self)

Available on crate feature NSResponder only.
pub fn postsFrameChangedNotifications(&self) -> bool

Available on crate feature NSResponder only.
pub fn setPostsFrameChangedNotifications( &self, posts_frame_changed_notifications: bool, )

Available on crate feature NSResponder only.
pub fn resizeSubviewsWithOldSize(&self, old_size: CGSize)

Available on crate feature NSResponder only.
pub fn resizeWithOldSuperviewSize(&self, old_size: CGSize)

Available on crate feature NSResponder only.
pub fn autoresizesSubviews(&self) -> bool

Available on crate feature NSResponder only.
pub fn setAutoresizesSubviews(&self, autoresizes_subviews: bool)

Available on crate feature NSResponder only.

Setter for autoresizesSubviews.

pub fn autoresizingMask(&self) -> NSAutoresizingMaskOptions

Available on crate feature NSResponder only.
pub fn setAutoresizingMask(&self, autoresizing_mask: NSAutoresizingMaskOptions)

Available on crate feature NSResponder only.

Setter for autoresizingMask.

pub fn setFrameOrigin(&self, new_origin: CGPoint)

Available on crate feature NSResponder only.
pub fn setFrameSize(&self, new_size: CGSize)

Available on crate feature NSResponder only.
pub fn frame(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn setFrame(&self, frame: CGRect)

Available on crate feature NSResponder only.

Setter for frame.

pub fn setBoundsOrigin(&self, new_origin: CGPoint)

Available on crate feature NSResponder only.
pub fn setBoundsSize(&self, new_size: CGSize)

Available on crate feature NSResponder only.
pub fn translateOriginToPoint(&self, translation: CGPoint)

Available on crate feature NSResponder only.
pub fn scaleUnitSquareToSize(&self, new_unit_size: CGSize)

Available on crate feature NSResponder only.
pub fn bounds(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn setBounds(&self, bounds: CGRect)

Available on crate feature NSResponder only.

Setter for bounds.

pub fn isFlipped(&self) -> bool

Available on crate feature NSResponder only.
pub fn isRotatedFromBase(&self) -> bool

Available on crate feature NSResponder only.
pub fn isRotatedOrScaledFromBase(&self) -> bool

Available on crate feature NSResponder only.
pub fn isOpaque(&self) -> bool

Available on crate feature NSResponder only.
pub fn convertPoint_fromView( &self, point: CGPoint, view: Option<&NSView>, ) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertPoint_toView( &self, point: CGPoint, view: Option<&NSView>, ) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertSize_fromView( &self, size: CGSize, view: Option<&NSView>, ) -> CGSize

Available on crate feature NSResponder only.
pub fn convertSize_toView(&self, size: CGSize, view: Option<&NSView>) -> CGSize

Available on crate feature NSResponder only.
pub fn convertRect_fromView( &self, rect: CGRect, view: Option<&NSView>, ) -> CGRect

Available on crate feature NSResponder only.
pub fn convertRect_toView(&self, rect: CGRect, view: Option<&NSView>) -> CGRect

Available on crate feature NSResponder only.
pub fn backingAlignedRect_options( &self, rect: CGRect, options: NSAlignmentOptions, ) -> CGRect

Available on crate feature NSResponder only.
pub fn centerScanRect(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertPointToBacking(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertPointFromBacking(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertSizeToBacking(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub fn convertSizeFromBacking(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub fn convertRectToBacking(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertRectFromBacking(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertPointToLayer(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertPointFromLayer(&self, point: CGPoint) -> CGPoint

Available on crate feature NSResponder only.
pub fn convertSizeToLayer(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub fn convertSizeFromLayer(&self, size: CGSize) -> CGSize

Available on crate feature NSResponder only.
pub fn convertRectToLayer(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn convertRectFromLayer(&self, rect: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn canDrawConcurrently(&self) -> bool

Available on crate feature NSResponder only.
pub unsafe fn setCanDrawConcurrently(&self, can_draw_concurrently: bool)

Available on crate feature NSResponder only.

Setter for canDrawConcurrently.

pub fn canDraw(&self) -> bool

👎Deprecated:

If a view needs display, -drawRect: or -updateLayer will be called automatically when the view is able to draw. To check whether a view is in a window, call -window. To check whether a view is hidden, call -isHiddenOrHasHiddenAncestor.

Available on crate feature NSResponder only.
pub fn setNeedsDisplayInRect(&self, invalid_rect: CGRect)

Available on crate feature NSResponder only.
pub fn needsDisplay(&self) -> bool

Available on crate feature NSResponder only.
pub fn setNeedsDisplay(&self, needs_display: bool)

Available on crate feature NSResponder only.

Setter for needsDisplay.

pub fn lockFocus(&self)

👎Deprecated:

To draw, subclass NSView and implement -drawRect:; AppKit’s automatic deferred display mechanism will call -drawRect: as necessary to display the view.

Available on crate feature NSResponder only.
pub fn unlockFocus(&self)

👎Deprecated:

To draw, subclass NSView and implement -drawRect:; AppKit’s automatic deferred display mechanism will call -drawRect: as necessary to display the view.

Available on crate feature NSResponder only.
pub fn lockFocusIfCanDraw(&self) -> bool

👎Deprecated:

To draw, subclass NSView and implement -drawRect:; AppKit’s automatic deferred display mechanism will call -drawRect: as necessary to display the view.

Available on crate feature NSResponder only.
pub fn visibleRect(&self) -> CGRect

Available on crate feature NSResponder only.

The portion of the view that isn’t clipped by its superviews.

Visibility, as reflected by this property, doesn’t account for whether other view or window objects overlap the current view or whether the current view is installed in a window at all. This value of this property is NSZeroRect if the current view is effectively hidden.

During a printing operation, the visible rectangle is further clipped to the page being imaged.

pub fn display(&self)

Available on crate feature NSResponder only.
pub fn displayIfNeeded(&self)

Available on crate feature NSResponder only.
pub fn displayIfNeededIgnoringOpacity(&self)

Available on crate feature NSResponder only.
pub fn displayRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn displayIfNeededInRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn displayRectIgnoringOpacity(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn displayIfNeededInRectIgnoringOpacity(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn drawRect(&self, dirty_rect: CGRect)

Available on crate feature NSResponder only.
pub fn viewWillDraw(&self)

Available on crate feature NSResponder only.
pub fn scrollPoint(&self, point: CGPoint)

Available on crate feature NSResponder only.
pub fn scrollRectToVisible(&self, rect: CGRect) -> bool

Available on crate feature NSResponder only.
pub fn adjustScroll(&self, new_visible: CGRect) -> CGRect

Available on crate feature NSResponder only.
pub fn scrollRect_by(&self, rect: CGRect, delta: CGSize)

👎Deprecated:

Use NSScrollView to achieve scrolling views.

Available on crate feature NSResponder only.
pub fn translateRectsNeedingDisplayInRect_by( &self, clip_rect: CGRect, delta: CGSize, )

Available on crate feature NSResponder only.
pub fn hitTest(&self, point: CGPoint) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub fn mouse_inRect(&self, point: CGPoint, rect: CGRect) -> bool

Available on crate feature NSResponder only.
pub fn viewWithTag(&self, tag: isize) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
pub fn tag(&self) -> isize

Available on crate feature NSResponder only.
pub fn needsPanelToBecomeKey(&self) -> bool

Available on crate feature NSResponder only.
pub fn mouseDownCanMoveWindow(&self) -> bool

Available on crate feature NSResponder only.
pub fn acceptsTouchEvents(&self) -> bool

👎Deprecated:

Use allowedTouchTypes instead

Available on crate feature NSResponder only.
pub fn setAcceptsTouchEvents(&self, accepts_touch_events: bool)

👎Deprecated:

Use allowedTouchTypes instead

Available on crate feature NSResponder only.

Setter for acceptsTouchEvents.

pub fn wantsRestingTouches(&self) -> bool

Available on crate feature NSResponder only.
pub fn setWantsRestingTouches(&self, wants_resting_touches: bool)

Available on crate feature NSResponder only.

Setter for wantsRestingTouches.

pub fn layerContentsRedrawPolicy(&self) -> NSViewLayerContentsRedrawPolicy

Available on crate feature NSResponder only.
pub fn setLayerContentsRedrawPolicy( &self, layer_contents_redraw_policy: NSViewLayerContentsRedrawPolicy, )

Available on crate feature NSResponder only.
pub fn layerContentsPlacement(&self) -> NSViewLayerContentsPlacement

Available on crate feature NSResponder only.
pub fn setLayerContentsPlacement( &self, layer_contents_placement: NSViewLayerContentsPlacement, )

Available on crate feature NSResponder only.
pub fn wantsLayer(&self) -> bool

Available on crate feature NSResponder only.
pub fn setWantsLayer(&self, wants_layer: bool)

Available on crate feature NSResponder only.

Setter for wantsLayer.

pub fn wantsUpdateLayer(&self) -> bool

Available on crate feature NSResponder only.
pub fn updateLayer(&self)

Available on crate feature NSResponder only.
pub fn canDrawSubviewsIntoLayer(&self) -> bool

Available on crate feature NSResponder only.
pub fn setCanDrawSubviewsIntoLayer(&self, can_draw_subviews_into_layer: bool)

Available on crate feature NSResponder only.
pub fn layoutSubtreeIfNeeded(&self)

Available on crate feature NSResponder only.
pub fn layout(&self)

Available on crate feature NSResponder only.
pub fn needsLayout(&self) -> bool

Available on crate feature NSResponder only.
pub fn setNeedsLayout(&self, needs_layout: bool)

Available on crate feature NSResponder only.

Setter for needsLayout.

pub fn layerUsesCoreImageFilters(&self) -> bool

Available on crate feature NSResponder only.
pub fn setLayerUsesCoreImageFilters(&self, layer_uses_core_image_filters: bool)

Available on crate feature NSResponder only.
pub fn clipsToBounds(&self) -> bool

Available on crate feature NSResponder only.
pub fn setClipsToBounds(&self, clips_to_bounds: bool)

Available on crate feature NSResponder only.

Setter for clipsToBounds.

pub fn postsBoundsChangedNotifications(&self) -> bool

Available on crate feature NSResponder only.
pub fn setPostsBoundsChangedNotifications( &self, posts_bounds_changed_notifications: bool, )

Available on crate feature NSResponder only.
pub fn toolTip(&self) -> Option<Retained<NSString>>

Available on crate feature NSResponder only.
pub fn setToolTip(&self, tool_tip: Option<&NSString>)

Available on crate feature NSResponder only.

Setter for toolTip.

This is copied when set.

pub unsafe fn addToolTipRect_owner_userData( &self, rect: CGRect, owner: &AnyObject, data: *mut c_void, ) -> isize

Available on crate feature NSResponder only.
Safety
  • owner should be of the correct type.
  • data must be a valid pointer or null.
pub fn removeToolTip(&self, tag: isize)

Available on crate feature NSResponder only.
pub fn removeAllToolTips(&self)

Available on crate feature NSResponder only.
pub fn viewWillStartLiveResize(&self)

Available on crate feature NSResponder only.
pub fn viewDidEndLiveResize(&self)

Available on crate feature NSResponder only.
pub fn inLiveResize(&self) -> bool

Available on crate feature NSResponder only.
pub fn preservesContentDuringLiveResize(&self) -> bool

Available on crate feature NSResponder only.
pub fn rectPreservedDuringLiveResize(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn rectForSmartMagnificationAtPoint_inRect( &self, location: CGPoint, visible_rect: CGRect, ) -> CGRect

Available on crate feature NSResponder only.
pub fn prepareForReuse(&self)

Available on crate feature NSResponder only.
pub fn prepareContentInRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn preparedContentRect(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn setPreparedContentRect(&self, prepared_content_rect: CGRect)

Available on crate feature NSResponder only.

Setter for preparedContentRect.

pub fn allowsVibrancy(&self) -> bool

Available on crate feature NSResponder only.
pub fn viewDidChangeEffectiveAppearance(&self)

Available on crate feature NSResponder only.

Override point for reacting to the effective appearance of the receiver changing. At this point effectiveAppearance property reflects the new appearance.

pub unsafe fn nextKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn setNextKeyView(&self, next_key_view: Option<&NSView>)

Available on crate feature NSResponder only.

Setter for nextKeyView.

Safety

This is unretained, you must ensure the object is kept alive while in use.

pub unsafe fn previousKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn nextValidKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn previousValidKeyView(&self) -> Option<Retained<NSView>>

Available on crate feature NSResponder only.
Safety

This is not retained internally, you must ensure the object is still alive.

pub fn canBecomeKeyView(&self) -> bool

Available on crate feature NSResponder only.
pub fn setKeyboardFocusRingNeedsDisplayInRect(&self, rect: CGRect)

Available on crate feature NSResponder only.
pub fn drawFocusRingMask(&self)

Available on crate feature NSResponder only.
pub fn focusRingMaskBounds(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn noteFocusRingMaskChanged(&self)

Available on crate feature NSResponder only.
pub fn dataWithEPSInsideRect(&self, rect: CGRect) -> Retained<NSData>

Available on crate feature NSResponder only.
pub fn dataWithPDFInsideRect(&self, rect: CGRect) -> Retained<NSData>

Available on crate feature NSResponder only.
pub unsafe fn print(&self, sender: Option<&AnyObject>)

Available on crate feature NSResponder only.
Safety

sender should be of the correct type.

pub unsafe fn knowsPageRange(&self, range: *mut NSRange) -> bool

Available on crate feature NSResponder only.
Safety

range must be a valid pointer.

pub fn rectForPage(&self, page: isize) -> CGRect

Available on crate feature NSResponder only.
pub fn locationOfPrintRect(&self, rect: CGRect) -> CGPoint

Available on crate feature NSResponder only.
pub fn drawPageBorderWithSize(&self, border_size: CGSize)

Available on crate feature NSResponder only.
pub fn pageHeader(&self) -> Retained<NSAttributedString>

Available on crate feature NSResponder only.
pub fn pageFooter(&self) -> Retained<NSAttributedString>

Available on crate feature NSResponder only.
pub fn drawSheetBorderWithSize(&self, border_size: CGSize)

👎Deprecated:

This is never invoked and the NSView implementation does nothing

Available on crate feature NSResponder only.
  • This method is obsolete. It will never be invoked from within AppKit, and NSView’s implementation of it does nothing. **
pub fn printJobTitle(&self) -> Retained<NSString>

Available on crate feature NSResponder only.
pub fn beginDocument(&self)

Available on crate feature NSResponder only.
pub fn endDocument(&self)

Available on crate feature NSResponder only.
pub fn beginPageInRect_atPlacement(&self, rect: CGRect, location: CGPoint)

Available on crate feature NSResponder only.
pub fn endPage(&self)

Available on crate feature NSResponder only.
pub fn unregisterDraggedTypes(&self)

Available on crate feature NSResponder only.
pub unsafe fn exitFullScreenModeWithOptions( &self, options: Option<&NSDictionary<NSString>>, )

Available on crate feature NSResponder only.
Safety

options generic should be of the correct type.

pub fn isInFullScreenMode(&self) -> bool

Available on crate feature NSResponder only.
pub fn showDefinitionForAttributedString_atPoint( &self, attr_string: Option<&NSAttributedString>, text_baseline_origin: CGPoint, )

Available on crate feature NSResponder only.
pub fn isDrawingFindIndicator(&self) -> bool

Available on crate feature NSResponder only.
pub fn safeAreaInsets(&self) -> NSEdgeInsets

Available on crate feature NSResponder only.
pub fn additionalSafeAreaInsets(&self) -> NSEdgeInsets

Available on crate feature NSResponder only.
pub fn setAdditionalSafeAreaInsets( &self, additional_safe_area_insets: NSEdgeInsets, )

Available on crate feature NSResponder only.
pub fn safeAreaRect(&self) -> CGRect

Available on crate feature NSResponder only.
pub fn prefersCompactControlSizeMetrics(&self) -> bool

Available on crate feature NSResponder only.

When this property is true, any NSControls in the view or its descendants will be sized with compact metrics compatible with macOS 15 and earlier. Defaults to false

pub fn setPrefersCompactControlSizeMetrics( &self, prefers_compact_control_size_metrics: bool, )

Available on crate feature NSResponder only.
pub fn updateTrackingAreas(&self)

Available on crate feature NSResponder only.
pub fn discardCursorRects(&self)

Available on crate feature NSResponder only.
pub fn resetCursorRects(&self)

Available on crate feature NSResponder only.
pub unsafe fn addTrackingRect_owner_userData_assumeInside( &self, rect: CGRect, owner: &AnyObject, data: *mut c_void, flag: bool, ) -> isize

Available on crate feature NSResponder only.
Safety
  • owner should be of the correct type.
  • data must be a valid pointer or null.
pub fn removeTrackingRect(&self, tag: isize)

Available on crate feature NSResponder only.
pub fn convertPointToBase(&self, point: CGPoint) -> CGPoint

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertPointFromBase(&self, point: CGPoint) -> CGPoint

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertSizeToBase(&self, size: CGSize) -> CGSize

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertSizeFromBase(&self, size: CGSize) -> CGSize

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertRectToBase(&self, rect: CGRect) -> CGRect

👎Deprecated
Available on crate feature NSResponder only.
pub fn convertRectFromBase(&self, rect: CGRect) -> CGRect

👎Deprecated
Available on crate feature NSResponder only.
pub fn performMnemonic(&self, string: &NSString) -> bool

👎Deprecated:

This has always returned NO and had no effect on macOS

Available on crate feature NSResponder only.
pub fn shouldDrawColor(&self) -> bool

👎Deprecated:

This method no longer does anything

Available on crate feature NSResponder only.
pub fn gState(&self) -> isize

👎Deprecated
Available on crate feature NSResponder only.
pub fn allocateGState(&self)

👎Deprecated
Available on crate feature NSResponder only.
pub fn setUpGState(&self)

👎Deprecated
Available on crate feature NSResponder only.
pub fn renewGState(&self)

👎Deprecated
Available on crate feature NSResponder only.

Methods from Deref<Target = NSResponder>

pub unsafe fn nextResponder(&self) -> Option<Retained<NSResponder>>

Safety

This is not retained internally, you must ensure the object is still alive.

pub unsafe fn setNextResponder(&self, next_responder: Option<&NSResponder>)

Setter for nextResponder.

Safety

This is unretained, you must ensure the object is kept alive while in use.

pub unsafe fn tryToPerform_with( &self, action: Sel, object: Option<&AnyObject>, ) -> bool

Safety
  • action must be a valid selector.
  • object should be of the correct type.
pub unsafe fn noResponderFor(&self, event_selector: Sel)

Safety

event_selector must be a valid selector.

pub fn acceptsFirstResponder(&self) -> bool

pub fn becomeFirstResponder(&self) -> bool

pub fn resignFirstResponder(&self) -> bool

pub fn flushBufferedKeyEvents(&self)

pub unsafe fn showContextHelp(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub unsafe fn supplementalTargetForAction_sender( &self, action: Sel, sender: Option<&AnyObject>, ) -> Option<Retained<AnyObject>>

Safety
  • action must be a valid selector.
  • sender should be of the correct type.
pub fn undoManager(&self) -> Option<Retained<NSUndoManager>>

pub unsafe fn presentError_modalForWindow_delegate_didPresentSelector_contextInfo( &self, error: &NSError, window: &NSWindow, delegate: Option<&AnyObject>, did_present_selector: Option<Sel>, context_info: *mut c_void, )

Available on crate feature NSWindow only.
Safety
  • delegate should be of the correct type.
  • did_present_selector must be a valid selector.
  • context_info must be a valid pointer or null.
pub fn presentError(&self, error: &NSError) -> bool

pub fn willPresentError(&self, error: &NSError) -> Retained<NSError>

pub unsafe fn performTextFinderAction(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub unsafe fn newWindowForTab(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub unsafe fn showWritingTools(&self, sender: Option<&AnyObject>)

Safety

sender should be of the correct type.

pub fn performMnemonic(&self, string: &NSString) -> bool

👎Deprecated:

This has always returned NO and had no effect on macOS

Methods from Deref<Target = NSObject>

pub fn doesNotRecognizeSelector(&self, sel: Sel) -> !

Handle messages the object doesn’t recognize.

See Apple’s documentation for details.

Methods from Deref<Target = AnyObject>

pub fn class(&self) -> &'static AnyClass

Dynamically find the class of this object.

Panics

May panic if the object is invalid (which may be the case for objects returned from unavailable init/new methods).

Example

Check that an instance of NSObject has the precise class NSObject.

use objc2::ClassType;
use objc2::runtime::NSObject;

let obj = NSObject::new();
assert_eq!(obj.class(), NSObject::class());
pub unsafe fn get_ivar<T>(&self, name: &str) -> &T
where T: Encode,

👎Deprecated:

this is difficult to use correctly, use Ivar::load instead.

Use Ivar::load instead.

Safety

The object must have an instance variable with the given name, and it must be of type T.

See Ivar::load_ptr for details surrounding this.

pub fn downcast_ref<T>(&self) -> Option<&T>
where T: DowncastTarget,

Attempt to downcast the object to a class of type T.

This is the reference-variant. Use Retained::downcast if you want to convert a retained object to another type.

Mutable classes

Some classes have immutable and mutable variants, such as NSString and NSMutableString.

When some Objective-C API signature says it gives you an immutable class, it generally expects you to not mutate that, even though it may technically be mutable “under the hood”.

So using this method to convert a NSString to a NSMutableString, while not unsound, is generally frowned upon unless you created the string yourself, or the API explicitly documents the string to be mutable.

See Apple’s documentation on mutability and on isKindOfClass: for more details.

Generic classes

Objective-C generics are called “lightweight generics”, and that’s because they aren’t exposed in the runtime. This makes it impossible to safely downcast to generic collections, so this is disallowed by this method.

You can, however, safely downcast to generic collections where all the type-parameters are AnyObject.

Panics

This works internally by calling isKindOfClass:. That means that the object must have the instance method of that name, and an exception will be thrown (if CoreFoundation is linked) or the process will abort if that is not the case. In the vast majority of cases, you don’t need to worry about this, since both root objects NSObject and NSProxy implement this method.

Examples

Cast an NSString back and forth from NSObject.

use objc2::rc::Retained;
use objc2_foundation::{NSObject, NSString};

let obj: Retained<NSObject> = NSString::new().into_super();
let string = obj.downcast_ref::<NSString>().unwrap();
// Or with `downcast`, if we do not need the object afterwards
let string = obj.downcast::<NSString>().unwrap();

Try (and fail) to cast an NSObject to an NSString.

use objc2_foundation::{NSObject, NSString};

let obj = NSObject::new();
assert!(obj.downcast_ref::<NSString>().is_none());

Try to cast to an array of strings.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);
// This is invalid and doesn't type check.
let arr = arr.downcast_ref::<NSArray<NSString>>();

This fails to compile, since it would require enumerating over the array to ensure that each element is of the desired type, which is a performance pitfall.

Downcast when processing each element instead.

use objc2_foundation::{NSArray, NSObject, NSString};

let arr = NSArray::from_retained_slice(&[NSObject::new()]);

for elem in arr {
    if let Some(data) = elem.downcast_ref::<NSString>() {
        // handle `data`
    }
}